@@ -763,7 +763,17 @@ class HDBSCAN(BaseEstimator, ClusterMixin):
     prediction_data_ : PredictionData object
         Cached data used for predicting the cluster labels of new or
         unseen points. Necessary only if you are using functions from
-        ``hdbscan.prediction``.
+        ``hdbscan.prediction`` (see
+        :func:`~hdbscan.prediction.approximate_predict`,
+        :func:`~hdbscan.prediction.membership_vector`,
+        and :func:`~hdbscan.prediction.all_points_membership_vectors`).
+
+    exemplars_ : list
+        A list of exemplar points for clusters. Since HDBSCAN supports
+        arbitrary shapes for clusters we cannot provide a single cluster
+        exemplar per cluster. Instead a list is returned with each element
+        of the list being a numpy array of exemplar points for a cluster --
+        these points are the "most representative" points of the cluster.
 
     References
     ----------
@@ -956,3 +966,16 @@ class HDBSCAN(BaseEstimator, ClusterMixin):
                  'This may be due to optimized algorithm variations that skip'
                  ' explicit generation of the spanning tree.')
             return None
+
+    @property
+    def exemplars_(self):
+        if self._prediction_data is not None:
+            return self._prediction_data.exemplars
+        elif self.metric in FAST_METRICS:
+            self.generate_prediction_data()
+            return self._prediction_data.exemplars
+        else:
+            warn('Currently exemplars require the use of vector input data'
+                 'with a suitable metric. This will likely change in the '
+                 'future, but for now no exemplars can be provided')
+            return None
