@@ -184,7 +184,10 @@ def _find_neighbor_and_lambda(neighbor_indices, neighbor_distances,
     nn_index = mr_distances.argmin()
 
     nearest_neighbor = neighbor_indices[nn_index]
-    lambda_ = 1. / mr_distances[nn_index]
+    if mr_distances[nn_index] > 0.0:
+        lambda_ = 1. / mr_distances[nn_index]
+    else:
+        lambda_ = np.finfo(np.double).max
 
     return nearest_neighbor, lambda_
 
@@ -327,7 +330,7 @@ def _find_cluster_and_probability(tree, cluster_tree, neighbor_indices,
 
 def approximate_predict(clusterer, points_to_predict):
     """Predict the cluster label of new points. The returned labels
-    will be those of the original clustering found by ``clustererer``,
+    will be those of the original clustering found by ``clusterer``,
     and therefore are not (necessarily) the cluster labels that would
     be found by clustering the original data combined with
     ``points_to_predict``, hence the 'approximate' label.
@@ -360,7 +363,8 @@ def approximate_predict(clusterer, points_to_predict):
 
     See Also
     --------
-    ``membership_vector``
+    :py:func:`hdbscan.predict.membership_vector`
+    :py:func:`hdbscan.predict.all_points_membership_vectors`
 
     """
     if clusterer.prediction_data_ is None:
@@ -422,7 +426,12 @@ def membership_vector(clusterer, points_to_predict):
     membership_vectors : array (n_samples, n_clusters)
         The probability that point ``i`` is a member of cluster ``j`` is
         in ``membership_vectors[i, j]``.
-    """
+
+    See Also
+    --------
+    :py:func:`hdbscan.predict.predict`
+    :py:func:`hdbscan.predict.all_points_membership_vectors`
+"""
 
     clusters = np.array(list(clusterer.condensed_tree_._select_clusters()
     )).astype(np.intp)
@@ -496,6 +505,11 @@ def all_points_membership_vectors(clusterer):
     membership_vectors : array (n_samples, n_clusters)
         The probability that point ``i`` of the original dataset is a member of
         cluster ``j`` is in ``membership_vectors[i, j]``.
+        
+    See Also
+    --------
+    :py:func:`hdbscan.predict.predict`
+    :py:func:`hdbscan.predict.all_points_membership_vectors`
     """
     clusters = np.array(list(clusterer.condensed_tree_._select_clusters()
                              )).astype(np.intp)
@@ -513,7 +527,7 @@ def all_points_membership_vectors(clusterer):
                                                        clusterer.prediction_data_.leaf_max_lambdas,
                                                        clusterer.prediction_data_.cluster_tree)
 
-    result = distance_vecs ** 0.5 * outlier_vecs ** 2.0
+    result = distance_vecs * outlier_vecs
     row_sums = result.sum(axis=1)
     result = result / row_sums[:, np.newaxis]
     result *= in_cluster_probs[:, np.newaxis]
